/// <reference types="node" />
import { GraphBase } from "./BaseGraph";
import { StatsManager } from "../StatsManager";
import { BarStats, BarGraphOptions } from "../types/types";
/** Class that generate Douhnout graph
 * @extends GraphBase
 */
declare class BarGraph extends GraphBase {
    fillColors: string[];
    displayOthers: boolean;
    /**
     * @param {StatsManager} statsmanager - Your StatsManager instance
     * @param {BarGraphOptions} options - options for the graph
     * @param {string[]} [options.fillColors = ["#ED4245", "#57F287", "#FEE75C", "#EB459E", "#FFFFFF", "#7289DA"]] - Colors of the doughnut
     * @param {boolean} [options.displayOthers = true] - Display the category others in doughnut
     * @param {number} [options.height = 400] - The height of the graph
     * @param {number} [options.width = 800] - The width of the graph
     * @param {number} [options.time = 604800000] - The time in miliseconds that the graph will display default is 1 week
     * @param {string} [options.color = "rgba(227, 227, 227, 0.9)"] - The color of the text and borders
     * @param {string} [options.backgroundColor = "rgba(40, 40, 40, 0.9)"] - The color of the background
     * @param {number} [options.fontSize = 14] - The font size of the text
     */
    constructor(statsmanager: StatsManager, options?: BarGraphOptions);
    /**
     * @param {BarStats[]} data - Data to generate the graph
     * @returns {Promise<Buffer>} - Promise that resolve to the generated graph
     */
    generateCanvas(data: BarStats[]): Promise<Buffer>;
}
export { BarGraph };
