/// <reference types="node" />
import { GraphBase } from "./BaseGraph";
import { StatsManager } from "../StatsManager";
import { LineGraphOptions, LineStats } from "../types/types";
/** The LineGraph class to generate linear graphics
 * @extends GraphBase
 */
declare class LineGraph extends GraphBase {
    lineColor: string;
    fillColor: string;
    dataSetName: string;
    /**
     * @param {StatsManager} statsmanager - Your StatsManager instance
     * @param {LineGraphOptions} options - The graph options
     * @param {string} [options.dataSetName = "Unamed"] - The name of the data set
     * @param {string} [options.lineColor = "rgba(255, 152, 56, 0.9)"] - The color of the line
     * @param {string} [options.fillColor = "rgba(255, 152, 56, 0.4)"] - The color that will fill the graph under the line
     * @param {number} [options.height = 400] - The height of the graph
     * @param {number} [options.width = 800] - The width of the graph
     * @param {number} [options.time = 604800000] - The time in miliseconds that the graph will display default is 1 week
     * @param {string} [options.color = "rgba(227, 227, 227, 0.9)"] - The color of the text and borders
     * @param {string} [options.backgroundColor = "rgba(40, 40, 40, 0.9)"] - The color of the background
     * @param {number} [options.fontSize = 14] - The font size of the text
     */
    constructor(statsmanager: StatsManager, options?: LineGraphOptions);
    /**
     * @param {LineStats[]} data - The data to generate the graph
     * @returns {Promise<Buffer>} - Promise that resolve to the generated graph
     */
    generateCanvas(data: LineStats[]): Promise<Buffer>;
}
export { LineGraph };
